@@ -5,50 +5,42 @@
 
 #include "parser.h"
 
-#include <ctype.h>
+#include <cctype>
 
 #include "kalzium_libscience_debug.h"
 
-
 Parser::Parser()
 {
     start(QString());
 }
 
-
-Parser::Parser(const QString& _str)
+Parser::Parser(const QString &_str)
 {
     start(_str);
 }
 
+Parser::~Parser() = default;
 
-Parser::~Parser()
-{
-}
-
-
-void Parser::start(const QString& _str)
+void Parser::start(const QString &_str)
 {
     m_str = _str;
 
     if (_str.isNull()) {
-        m_index     = -1;
-        m_nextChar  = -1;
+        m_index = -1;
+        m_nextChar = -1;
         m_nextToken = -1;
     } else {
-        m_index     = 0;
-        m_nextChar  = m_str.at(0).toLatin1();
+        m_index = 0;
+        m_nextChar = m_str.at(0).toLatin1();
         getNextToken();
     }
 }
 
-
 // ----------------------------------------------------------------
 
-
 // Skip whitespace, and try to parse the following characters as an int.
 //
-// Return true if successful.  
+// Return true if successful.
 
 bool Parser::parseInt(int *_result)
 {
@@ -65,7 +57,7 @@ bool Parser::parseInt(int *_result)
         return false;
     }
 
-    int  result = 0;
+    int result = 0;
     while (isdigit(m_nextChar)) {
         result = result * 10 + (m_nextChar - '0');
         getNextChar();
@@ -75,15 +67,14 @@ bool Parser::parseInt(int *_result)
     return true;
 }
 
-
 // Skip whitespace, and try to parse the following characters as a
 // simple float of the type -?[0-9]+'.'?[0-9]*
 //
-// Return true if successful.  
+// Return true if successful.
 
 bool Parser::parseSimpleFloat(double *_result)
 {
-    double  sign = 1.0;
+    double sign = 1.0;
 
     skipWhitespace();
     if (m_nextChar == '-') {
@@ -109,7 +100,7 @@ bool Parser::parseSimpleFloat(double *_result)
         return true;
     }
 
-    double  decimal = 0.1;
+    double decimal = 0.1;
     while (isdigit(m_nextChar)) {
         result += decimal * (double)(m_nextChar - '0');
         decimal /= 10.0;
@@ -125,8 +116,8 @@ bool Parser::parseSimpleFloat(double *_result)
 
 int Parser::getNextChar()
 {
-//    qCDebug(KALZIUM_LIBSCIENCE_LOG) << "Parser::getNextChar(): char = " << m_nextChar;
-//    qCDebug(KALZIUM_LIBSCIENCE_LOG) << "m_str.size() " << m_str.size()  << " with m_str: " << m_str  << " and m_index: " << m_index;
+    //    qCDebug(KALZIUM_LIBSCIENCE_LOG) << "Parser::getNextChar(): char = " << m_nextChar;
+    //    qCDebug(KALZIUM_LIBSCIENCE_LOG) << "m_str.size() " << m_str.size()  << " with m_str: " << m_str  << " and m_index: " << m_index;
 
     ++m_index;
 
@@ -136,7 +127,7 @@ int Parser::getNextChar()
 
     // If end of string, then reset the parser.
     if (m_index == m_str.size()) {
-        m_index    = -1;
+        m_index = -1;
         m_nextChar = -1;
     } else {
         m_nextChar = m_str.at(m_index).toLatin1();
@@ -144,14 +135,13 @@ int Parser::getNextChar()
 
     // Take care of null-terminated strings.
     if (m_nextChar == 0) {
-        m_index    = -1;
+        m_index = -1;
         m_nextChar = -1;
     }
 
     return m_nextChar;
 }
 
-
 int Parser::skipWhitespace()
 {
     while (QChar(m_nextChar).isSpace()) {
@@ -161,7 +151,6 @@ int Parser::skipWhitespace()
     return m_nextChar;
 }
 
-
 // Get the next token.  This corresponds to the lexical analyzer of a
 // standard parser, e.g as generated by lex.
 //
@@ -185,7 +174,7 @@ int Parser::getNextToken()
             m_index = saveIndex;
 
             // No need to check since we already know it is correct.
-            (void) parseSimpleFloat(&m_floatVal);
+            (void)parseSimpleFloat(&m_floatVal);
             m_nextToken = FLOAT_TOKEN;
         } else {
             m_nextToken = INT_TOKEN;
